@@ -552,6 +552,11 @@ impl SpircTask {
             }
         }
 
+        // this should clear the active session id, leaving an empty state
+        if let Err(why) = self.session.spclient().delete_connect_state_request().await {
+            error!("error during connect state deletion: {why}")
+        };
+
         self.session.dealer().close().await;
     }
 
@@ -1163,12 +1168,6 @@ impl SpircTask {
 
         self.connect_state.became_inactive(&self.session).await?;
 
-        // this should clear the active session id, leaving an empty state
-        self.session
-            .spclient()
-            .delete_connect_state_request()
-            .await?;
-
         self.player
             .emit_session_disconnected_event(self.session.connection_id(), self.session.username());
 
@@ -1288,7 +1287,7 @@ impl SpircTask {
             if self.context_resolver.has_next() {
                 self.connect_state.update_queue_revision()
             } else {
-                self.connect_state.shuffle(None)?;
+                self.connect_state.shuffle_new()?;
                 self.add_autoplay_resolving_when_required();
             }
         } else {
