@@ -36,7 +36,7 @@ async fn main() {
     println!("Connecting...");
     let session = Session::new(session_config, None);
     if let Err(e) = session.connect(credentials, false).await {
-        println!("Error connecting: {}", e);
+        println!("Error connecting: {e}");
         exit(1);
     }
 
